# Ollachat 🚀

> **TL;DR** A minimal Streamlit Chatbot with Ollama models

A Streamlit chatbot app that integrates with the Ollama LLMs. Includes Chat history; and each model has its own log history.


## Getting started


1) Install the pacakge (in virtualenv recommended)

```bash
pip install st_ollama
```

2) Start the app

```bash
ollachat
```

### Notes

- [Ollama](http://ollama.ai/) must be installed.
- Supports macOS and Linux.